@@ -338,6 +338,12 @@ def create_parser(
         from ..commands.cleanup import add_cleanup_parser
 
         add_cleanup_parser(subparsers)
+
+        # MCP pipx configuration command
+        if hasattr(CLICommands, "MCP_PIPX_CONFIG") or True:  # Always add for now
+            from ..commands.mcp_pipx_config import add_parser as add_mcp_pipx_parser
+            
+            add_mcp_pipx_parser(subparsers)
         
         from ..commands.doctor import add_doctor_parser
         
