@@ -19,11 +19,13 @@ import { EventViewer } from '@components/event-viewer.js';
 import { ModuleViewer } from '@components/module-viewer.js';
 import { SessionManager } from '@components/session-manager.js';
 import { AgentInference } from '@components/agent-inference.js';
+import { AgentHierarchy } from '@components/agent-hierarchy.js';
 import { UIStateManager } from '@components/ui-state-manager.js';
 import { EventProcessor } from '@components/event-processor.js';
 import { ExportManager } from '@components/export-manager.js';
 import { WorkingDirectoryManager } from '@components/working-directory.js';
 import { FileToolTracker } from '@components/file-tool-tracker.js';
+import { BuildTracker } from '@components/build-tracker.js';
 class Dashboard {
     constructor() {
         // Core components (existing)
@@ -34,11 +36,13 @@ class Dashboard {
         // New modular components
         this.socketManager = null;
         this.agentInference = null;
+        this.agentHierarchy = null;
         this.uiStateManager = null;
         this.eventProcessor = null;
         this.exportManager = null;
         this.workingDirectoryManager = null;
         this.fileToolTracker = null;
+        this.buildTracker = null;
 
         // Initialize the dashboard
         this.init();
@@ -50,23 +54,75 @@ class Dashboard {
     init() {
         console.log('Initializing refactored Claude MPM Dashboard...');
 
-        // Initialize modules in dependency order
-        this.initializeSocketManager();
-        this.initializeCoreComponents();
-        this.initializeAgentInference();
-        this.initializeUIStateManager();
-        this.initializeWorkingDirectoryManager();
-        this.initializeFileToolTracker();
-        this.initializeEventProcessor();
-        this.initializeExportManager();
+        try {
+            // Initialize modules in dependency order
+            this.initializeSocketManager();
+            this.initializeCoreComponents();
+            this.initializeBuildTracker();
+            this.initializeAgentInference();
+            this.initializeAgentHierarchy();
+            this.initializeUIStateManager();
+            this.initializeWorkingDirectoryManager();
+            this.initializeFileToolTracker();
+            this.initializeEventProcessor();
+            this.initializeExportManager();
 
-        // Set up inter-module communication
-        this.setupModuleInteractions();
+            // Set up inter-module communication
+            this.setupModuleInteractions();
 
-        // Initialize from URL parameters
-        this.initializeFromURL();
+            // Initialize from URL parameters
+            this.initializeFromURL();
 
-        console.log('Claude MPM Dashboard initialized successfully');
+            console.log('Claude MPM Dashboard initialized successfully');
+        } catch (error) {
+            console.error('Error during dashboard initialization:', error);
+            // Re-throw to be caught by DOMContentLoaded handler
+            throw error;
+        }
+    }
+    
+    /**
+     * Validate that all critical components are initialized
+     * WHY: Ensures dashboard is in a valid state after initialization
+     */
+    validateInitialization() {
+        const criticalComponents = [
+            { name: 'socketManager', component: this.socketManager },
+            { name: 'eventViewer', component: this.eventViewer },
+            { name: 'agentHierarchy', component: this.agentHierarchy }
+        ];
+        
+        const missing = criticalComponents.filter(c => !c.component);
+        if (missing.length > 0) {
+            console.warn('Missing critical components:', missing.map(c => c.name));
+        } else {
+            console.log('All critical components initialized');
+        }
+    }
+
+    /**
+     * Post-initialization setup that requires window.dashboard to be set
+     * WHY: Some components need to reference window.dashboard but it's not available
+     * during constructor execution. This method is called after the Dashboard instance
+     * is assigned to window.dashboard, ensuring proper initialization order.
+     * 
+     * DESIGN DECISION: Separate post-init phase prevents "cannot read property of undefined"
+     * errors when components try to access window.dashboard during construction.
+     */
+    postInit() {
+        try {
+            // Set global reference for agent hierarchy after dashboard is available
+            if (this.agentHierarchy) {
+                window.dashboard.agentHierarchy = this.agentHierarchy;
+                console.log('Agent hierarchy global reference set');
+            }
+            
+            // Initialize any other components that need window.dashboard
+            this.validateInitialization();
+        } catch (error) {
+            console.error('Error in dashboard postInit:', error);
+            // Continue execution - non-critical error
+        }
     }
 
     /**
@@ -98,6 +154,28 @@ class Dashboard {
         window.sessionManager = this.sessionManager;
     }
 
+    /**
+     * Initialize build tracker
+     */
+    initializeBuildTracker() {
+        this.buildTracker = new BuildTracker();
+        
+        // Set the socket client for receiving updates
+        this.buildTracker.setSocketClient(this.socketClient);
+        
+        // Mount to header - find the best location
+        const headerTitle = document.querySelector('.header-title');
+        if (headerTitle) {
+            // Insert after the title and status badge
+            this.buildTracker.mount(headerTitle);
+        } else {
+            console.warn('Could not find header-title element for build tracker');
+        }
+        
+        // Make available globally for debugging
+        window.buildTracker = this.buildTracker;
+    }
+
     /**
      * Initialize agent inference system
      */
@@ -105,6 +183,28 @@ class Dashboard {
         this.agentInference = new AgentInference(this.eventViewer);
         this.agentInference.initialize();
     }
+    
+    /**
+     * Initialize agent hierarchy component
+     * WHY: Creates the agent hierarchy visualization component but defers global
+     * reference setting to postInit() to avoid initialization order issues.
+     */
+    initializeAgentHierarchy() {
+        try {
+            this.agentHierarchy = new AgentHierarchy(this.agentInference, this.eventViewer);
+            // Global reference will be set in postInit() after window.dashboard exists
+            console.log('Agent hierarchy component created');
+        } catch (error) {
+            console.error('Failed to initialize agent hierarchy:', error);
+            // Create a stub to prevent further errors
+            this.agentHierarchy = {
+                render: () => '<div class="error">Agent hierarchy unavailable</div>',
+                expandAllNodes: () => {},
+                collapseAllNodes: () => {},
+                updateWithNewEvents: () => {}
+            };
+        }
+    }
 
     /**
      * Initialize UI state manager
@@ -154,6 +254,9 @@ class Dashboard {
 
             // Process agent inference for new events
             this.agentInference.processAgentInference();
+            
+            // Update agent hierarchy with new events
+            this.agentHierarchy.updateWithNewEvents(events);
 
             // Auto-scroll events list if on events tab
             if (this.uiStateManager.getCurrentTab() === 'events') {
@@ -291,26 +394,74 @@ class Dashboard {
     }
 
     /**
-     * Render agents tab with unique instance view (one row per PM delegation)
+     * Render agents tab with hierarchical view
      */
     renderAgents() {
         const agentsList = document.getElementById('agents-list');
         if (!agentsList) return;
-
-        // Process agent inference to get PM delegations
-        this.agentInference.processAgentInference();
-
-        // Generate HTML for unique agent instances
-        const events = this.eventProcessor.getFilteredEventsForTab('agents');
-        const agentHTML = this.eventProcessor.generateAgentHTML(events);
-
-        agentsList.innerHTML = agentHTML;
-        this.exportManager.scrollListToBottom('agents-list');
-
-        // Update filter dropdowns with unique instances
+        
+        // Get filter values
+        const searchText = document.getElementById('agents-search-input')?.value || '';
+        const agentType = document.getElementById('agents-type-filter')?.value || '';
+        
+        // Build filters object
+        const filters = {};
+        if (searchText) filters.searchText = searchText;
+        if (agentType) filters.agentType = agentType;
+        
+        // Generate hierarchical HTML
+        const hierarchyHTML = this.agentHierarchy.render(filters);
+        agentsList.innerHTML = hierarchyHTML;
+        
+        // Add expand/collapse all buttons if not present
+        this.addHierarchyControls();
+        
+        // Update filter dropdowns with available agent types
         const uniqueInstances = this.agentInference.getUniqueAgentInstances();
         this.updateAgentsFilterDropdowns(uniqueInstances);
     }
+    
+    /**
+     * Add hierarchy control buttons
+     */
+    addHierarchyControls() {
+        const tabFilters = document.querySelector('#agents-tab .tab-filters');
+        if (!tabFilters) return;
+        
+        // Check if controls already exist
+        if (document.getElementById('hierarchy-controls')) return;
+        
+        // Create control buttons
+        const controls = document.createElement('div');
+        controls.id = 'hierarchy-controls';
+        controls.className = 'hierarchy-controls';
+        controls.innerHTML = `
+            <button data-action="expand-all" 
+                    class="hierarchy-btn hierarchy-expand-all">
+                Expand All
+            </button>
+            <button data-action="collapse-all" 
+                    class="hierarchy-btn hierarchy-collapse-all">
+                Collapse All
+            </button>
+        `;
+        
+        // Add safe event listeners
+        controls.addEventListener('click', (event) => {
+            const action = event.target.dataset.action;
+            if (action && window.dashboard && window.dashboard.agentHierarchy) {
+                if (action === 'expand-all') {
+                    window.dashboard.agentHierarchy.expandAllNodes();
+                    window.dashboard.renderAgents();
+                } else if (action === 'collapse-all') {
+                    window.dashboard.agentHierarchy.collapseAllNodes();
+                    window.dashboard.renderAgents();
+                }
+            }
+        });
+        
+        tabFilters.appendChild(controls);
+    }
 
     /**
      * Render tools tab with unique instance view (one row per unique tool call)
@@ -1683,6 +1834,122 @@ function displayFileContentError(modal, result) {
     errorArea.style.display = 'block';
 }
 
+// Search Viewer Modal Functions
+window.showSearchViewerModal = function(searchParams, searchResults) {
+    // Create modal if it doesn't exist
+    let modal = document.getElementById('search-viewer-modal');
+    if (!modal) {
+        modal = createSearchViewerModal();
+        document.body.appendChild(modal);
+    }
+
+    // Update modal content
+    updateSearchViewerModal(modal, searchParams, searchResults);
+
+    // Show the modal as flex container
+    modal.style.display = 'flex';
+    document.body.style.overflow = 'hidden'; // Prevent background scrolling
+};
+
+window.hideSearchViewerModal = function() {
+    const modal = document.getElementById('search-viewer-modal');
+    if (modal) {
+        modal.style.display = 'none';
+        document.body.style.overflow = ''; // Restore background scrolling
+    }
+};
+
+function createSearchViewerModal() {
+    const modal = document.createElement('div');
+    modal.id = 'search-viewer-modal';
+    modal.className = 'modal search-viewer-modal';
+
+    modal.innerHTML = `
+        <div class="modal-content search-viewer-content">
+            <div class="search-viewer-header">
+                <h2 class="search-viewer-title">
+                    <span class="search-viewer-icon">🔍</span>
+                    <span class="search-viewer-title-text">Search Results</span>
+                </h2>
+                <button class="search-viewer-close" onclick="hideSearchViewerModal()">
+                    <span>&times;</span>
+                </button>
+            </div>
+            <div class="search-viewer-body">
+                <div class="search-params-section">
+                    <h3>Search Parameters</h3>
+                    <pre class="search-params-display"></pre>
+                </div>
+                <div class="search-results-section">
+                    <h3>Search Results</h3>
+                    <div class="search-results-display"></div>
+                </div>
+            </div>
+        </div>
+    `;
+
+    // Close modal when clicking outside
+    modal.addEventListener('click', (e) => {
+        if (e.target === modal) {
+            hideSearchViewerModal();
+        }
+    });
+
+    // Close modal on Escape key
+    document.addEventListener('keydown', (e) => {
+        if (e.key === 'Escape' && modal.style.display === 'flex') {
+            hideSearchViewerModal();
+        }
+    });
+
+    return modal;
+}
+
+function updateSearchViewerModal(modal, searchParams, searchResults) {
+    const paramsDisplay = modal.querySelector('.search-params-display');
+    const resultsDisplay = modal.querySelector('.search-results-display');
+
+    // Display search parameters in formatted JSON
+    if (paramsDisplay && searchParams) {
+        paramsDisplay.textContent = JSON.stringify(searchParams, null, 2);
+    }
+
+    // Display search results
+    if (resultsDisplay && searchResults) {
+        let resultsHTML = '';
+        
+        if (typeof searchResults === 'string') {
+            // If results are a string, display as preformatted text
+            resultsHTML = `<pre class="search-results-text">${escapeHtml(searchResults)}</pre>`;
+        } else if (Array.isArray(searchResults)) {
+            // If results are an array, display as a list
+            resultsHTML = '<ul class="search-results-list">';
+            searchResults.forEach(result => {
+                if (typeof result === 'object') {
+                    resultsHTML += `<li><pre>${JSON.stringify(result, null, 2)}</pre></li>`;
+                } else {
+                    resultsHTML += `<li>${escapeHtml(String(result))}</li>`;
+                }
+            });
+            resultsHTML += '</ul>';
+        } else if (typeof searchResults === 'object') {
+            // If results are an object, display as formatted JSON
+            resultsHTML = `<pre class="search-results-json">${JSON.stringify(searchResults, null, 2)}</pre>`;
+        } else {
+            // Fallback: display as text
+            resultsHTML = `<div class="search-results-text">${escapeHtml(String(searchResults))}</div>`;
+        }
+        
+        resultsDisplay.innerHTML = resultsHTML;
+    }
+}
+
+function escapeHtml(text) {
+    const div = document.createElement('div');
+    div.textContent = text;
+    return div.innerHTML;
+}
+
 // Global window functions for backward compatibility
 window.showAgentInstanceDetails = function(instanceId) {
     if (window.dashboard && typeof window.dashboard.showAgentInstanceDetails === 'function') {
@@ -1694,8 +1961,33 @@ window.showAgentInstanceDetails = function(instanceId) {
 
 // Initialize dashboard when page loads
 document.addEventListener('DOMContentLoaded', function() {
-    window.dashboard = new Dashboard();
-    console.log('Dashboard loaded and initialized');
+    try {
+        // Create dashboard instance
+        window.dashboard = new Dashboard();
+        
+        // Call post-initialization setup that requires window.dashboard
+        // This must happen after window.dashboard is set
+        if (window.dashboard && typeof window.dashboard.postInit === 'function') {
+            window.dashboard.postInit();
+        }
+        
+        console.log('Dashboard loaded and initialized successfully');
+        
+        // Dispatch custom event to signal dashboard ready
+        document.dispatchEvent(new CustomEvent('dashboardReady', {
+            detail: { dashboard: window.dashboard }
+        }));
+    } catch (error) {
+        console.error('Failed to initialize dashboard:', error);
+        // Show user-friendly error message
+        document.body.innerHTML = `
+            <div style="padding: 20px; font-family: sans-serif;">
+                <h1>Dashboard Initialization Error</h1>
+                <p>The dashboard failed to load properly. Please refresh the page or check the console for details.</p>
+                <pre style="background: #f5f5f5; padding: 10px; border-radius: 4px;">${error.message}</pre>
+            </div>
+        `;
+    }
 });
 
 // ES6 Module export
