@@ -45,6 +45,7 @@ from claude_mpm.core.logging_config import (
     log_operation,
     log_performance_context,
 )
+from claude_mpm.services.shared import ConfigServiceBase
 
 from .agent_configuration_manager import AgentConfigurationManager
 from .agent_discovery_service import AgentDiscoveryService
@@ -58,7 +59,7 @@ from .agent_version_manager import AgentVersionManager
 from .multi_source_deployment_service import MultiSourceAgentDeploymentService
 
 
-class AgentDeploymentService(AgentDeploymentInterface):
+class AgentDeploymentService(ConfigServiceBase, AgentDeploymentInterface):
     """Service for deploying Claude Code native agents.
 
     METRICS COLLECTION OPPORTUNITIES:
@@ -94,6 +95,7 @@ class AgentDeploymentService(AgentDeploymentInterface):
         templates_dir: Optional[Path] = None,
         base_agent_path: Optional[Path] = None,
         working_directory: Optional[Path] = None,
+        config: Optional[Config] = None,
     ):
         """
         Initialize agent deployment service.
@@ -102,13 +104,15 @@ class AgentDeploymentService(AgentDeploymentInterface):
             templates_dir: Directory containing agent JSON files
             base_agent_path: Path to base_agent.md file
             working_directory: User's working directory (for project agents)
+            config: Configuration instance
 
         METRICS OPPORTUNITY: Track initialization performance:
         - Template directory scan time
         - Base agent loading time
         - Initial validation overhead
         """
-        self.logger = get_logger(__name__)
+        # Initialize base class with configuration
+        super().__init__("agent_deployment", config=config)
 
         # Initialize template builder service
         self.template_builder = AgentTemplateBuilder()
@@ -139,26 +143,22 @@ class AgentDeploymentService(AgentDeploymentInterface):
             "deployment_errors": {},
         }
 
-        # Determine the actual working directory
-        # For deployment, we need to track the working directory but NOT use it
-        # for determining where system agents go (they always go to ~/.claude/agents/)
-        # Priority: working_directory param > current directory
-        if working_directory:
-            self.working_directory = Path(working_directory)
-        else:
-            # Use current directory but don't let CLAUDE_MPM_USER_PWD affect system agent deployment
-            self.working_directory = Path.cwd()
-
+        # Determine the actual working directory using configuration
+        # Priority: param > config > environment > current directory
+        self.working_directory = self.get_config_value(
+            "working_directory",
+            default=working_directory or Path.cwd(),
+            config_type=Path
+        )
         self.logger.info(f"Working directory for deployment: {self.working_directory}")
 
-        # Find templates directory using centralized path management
-        if templates_dir:
-            self.templates_dir = Path(templates_dir)
-        else:
-            # Use centralized paths instead of fragile parent calculations
-            # For system agents, still use templates subdirectory
-            # For project/user agents, this should be overridden with actual agents dir
-            self.templates_dir = paths.agents_dir / "templates"
+        # Find templates directory using configuration
+        # Priority: param > config > default paths
+        self.templates_dir = self.get_config_value(
+            "templates_dir",
+            default=templates_dir or paths.agents_dir / "templates",
+            config_type=Path
+        )
 
         # Initialize discovery service (after templates_dir is set)
         self.discovery_service = AgentDiscoveryService(self.templates_dir)
@@ -166,9 +166,13 @@ class AgentDeploymentService(AgentDeploymentInterface):
         # Initialize multi-source deployment service for version comparison
         self.multi_source_service = MultiSourceAgentDeploymentService()
 
-        # Find base agent file with priority-based search
+        # Find base agent file using configuration
+        # Priority: param > config > search
+        configured_base_agent = self.get_config_value("base_agent_path", config_type=Path)
         if base_agent_path:
             self.base_agent_path = Path(base_agent_path)
+        elif configured_base_agent:
+            self.base_agent_path = configured_base_agent
         else:
             # Priority-based search for base_agent.json
             self.base_agent_path = self._find_base_agent_file()
@@ -381,12 +385,23 @@ class AgentDeploymentService(AgentDeploymentInterface):
             
             if use_multi_source:
                 # Use multi-source deployment to get highest version agents
-                template_files, agent_sources = self._get_multi_source_templates(
-                    excluded_agents, config, agents_dir
+                template_files, agent_sources, cleanup_results = self._get_multi_source_templates(
+                    excluded_agents, config, agents_dir, force_rebuild
                 )
                 results["total"] = len(template_files)
                 results["multi_source"] = True
                 results["agent_sources"] = agent_sources
+                results["cleanup"] = cleanup_results
+                
+                # Log cleanup results if any agents were removed
+                if cleanup_results.get("removed"):
+                    self.logger.info(
+                        f"Cleaned up {len(cleanup_results['removed'])} outdated user agents"
+                    )
+                    for removed in cleanup_results["removed"]:
+                        self.logger.debug(
+                            f"  - Removed: {removed['name']} v{removed['version']} ({removed['reason']})"
+                        )
             else:
                 # Get and filter template files from single source
                 template_files = self._get_filtered_templates(excluded_agents, config)
@@ -412,8 +427,12 @@ class AgentDeploymentService(AgentDeploymentInterface):
                     source_info=source_info,
                 )
 
-            # Deploy system instructions and framework files
-            self._deploy_system_instructions(agents_dir, force_rebuild, results)
+            # CRITICAL: System instructions deployment disabled to prevent automatic file creation
+            # The system should NEVER automatically write INSTRUCTIONS.md, MEMORY.md, WORKFLOW.md
+            # to .claude/ directory. These files should only be created when explicitly requested
+            # by the user through agent-manager commands.
+            # See deploy_system_instructions_explicit() for manual deployment.
+            # self._deploy_system_instructions(agents_dir, force_rebuild, results)
 
             self.logger.info(
                 f"Deployed {len(results['deployed'])} agents, "
@@ -508,11 +527,11 @@ class AgentDeploymentService(AgentDeploymentInterface):
                 return False
 
             # Ensure target directory exists
-            agents_dir = target_dir / ".claude" / "agents"
-            agents_dir.mkdir(parents=True, exist_ok=True)
+            # target_dir should already be the agents directory
+            target_dir.mkdir(parents=True, exist_ok=True)
 
             # Build and deploy the agent
-            target_file = agents_dir / f"{agent_name}.md"
+            target_file = target_dir / f"{agent_name}.md"
 
             # Check if update is needed
             if not force_rebuild and target_file.exists():
@@ -610,9 +629,64 @@ class AgentDeploymentService(AgentDeploymentInterface):
 
         deployer = SystemInstructionsDeployer(self.logger, self.working_directory)
         deployer.deploy_system_instructions(
-            target_dir, force_rebuild, results, self._is_project_specific_deployment()
+            target_dir, force_rebuild, results
         )
 
+    def deploy_system_instructions_explicit(
+        self, target_dir: Optional[Path] = None, force_rebuild: bool = False
+    ) -> Dict[str, Any]:
+        """
+        Explicitly deploy system instructions when requested by user.
+        
+        This method should ONLY be called when the user explicitly requests
+        deployment of system instructions through agent-manager commands.
+        It will deploy INSTRUCTIONS.md, MEMORY.md, and WORKFLOW.md to .claude/
+        directory in the project.
+        
+        Args:
+            target_dir: Target directory for deployment (ignored - always uses .claude/)
+            force_rebuild: Force rebuild even if files exist
+            
+        Returns:
+            Dict with deployment results
+        """
+        results = {
+            "deployed": [],
+            "updated": [],
+            "skipped": [],
+            "errors": [],
+        }
+        
+        try:
+            # Always use project's .claude directory
+            target_dir = self.working_directory / ".claude"
+            
+            # Ensure directory exists
+            target_dir.mkdir(parents=True, exist_ok=True)
+            
+            # Deploy using the deployer (targeting .claude/)
+            from .system_instructions_deployer import SystemInstructionsDeployer
+            deployer = SystemInstructionsDeployer(self.logger, self.working_directory)
+            
+            # Deploy to .claude directory
+            deployer.deploy_system_instructions(
+                target_dir, force_rebuild, results
+            )
+            
+            self.logger.info(
+                f"Explicitly deployed system instructions to {target_dir}: "
+                f"deployed={len(results['deployed'])}, "
+                f"updated={len(results['updated'])}, "
+                f"skipped={len(results['skipped'])}"
+            )
+            
+        except Exception as e:
+            error_msg = f"Failed to deploy system instructions: {e}"
+            self.logger.error(error_msg)
+            results["errors"].append(error_msg)
+        
+        return results
+
     def _convert_yaml_to_md(self, target_dir: Path) -> Dict[str, Any]:
         """Convert existing YAML agent files to MD format with YAML frontmatter."""
         return self.format_converter.convert_yaml_to_md(target_dir)
@@ -697,32 +771,9 @@ class AgentDeploymentService(AgentDeploymentInterface):
         """Determine the correct agents directory based on input."""
         from .agents_directory_resolver import AgentsDirectoryResolver
 
-        resolver = AgentsDirectoryResolver(
-            self.working_directory,
-            self._is_system_agent_deployment(),
-            self._is_project_specific_deployment(),
-        )
+        resolver = AgentsDirectoryResolver(self.working_directory)
         return resolver.determine_agents_directory(target_dir)
 
-    def _is_system_agent_deployment(self) -> bool:
-        """Check if this is a deployment of system agents."""
-        from .deployment_type_detector import DeploymentTypeDetector
-
-        return DeploymentTypeDetector.is_system_agent_deployment(self.templates_dir)
-
-    def _is_project_specific_deployment(self) -> bool:
-        """Check if deploying project-specific agents."""
-        from .deployment_type_detector import DeploymentTypeDetector
-
-        return DeploymentTypeDetector.is_project_specific_deployment(
-            self.templates_dir, self.working_directory
-        )
-
-    def _is_user_custom_deployment(self) -> bool:
-        """Check if deploying user custom agents."""
-        from .deployment_type_detector import DeploymentTypeDetector
-
-        return DeploymentTypeDetector.is_user_custom_deployment(self.templates_dir)
 
     def _initialize_deployment_results(
         self, agents_dir: Path, deployment_start_time: float
@@ -1056,8 +1107,9 @@ class AgentDeploymentService(AgentDeploymentInterface):
         return False
     
     def _get_multi_source_templates(
-        self, excluded_agents: List[str], config: Config, agents_dir: Path
-    ) -> Tuple[List[Path], Dict[str, str]]:
+        self, excluded_agents: List[str], config: Config, agents_dir: Path, 
+        force_rebuild: bool = False
+    ) -> Tuple[List[Path], Dict[str, str], Dict[str, Any]]:
         """Get agent templates from multiple sources with version comparison.
         
         WHY: This method uses the multi-source service to discover agents
@@ -1067,9 +1119,10 @@ class AgentDeploymentService(AgentDeploymentInterface):
             excluded_agents: List of agents to exclude
             config: Configuration object
             agents_dir: Target deployment directory
+            force_rebuild: Whether to force rebuild
             
         Returns:
-            Tuple of (template_files, agent_sources)
+            Tuple of (template_files, agent_sources, cleanup_results)
         """
         # Determine source directories
         system_templates_dir = self.templates_dir
@@ -1090,14 +1143,15 @@ class AgentDeploymentService(AgentDeploymentInterface):
             user_agents_dir = potential_user_dir
             self.logger.info(f"Found user agents at: {user_agents_dir}")
         
-        # Get agents with version comparison
-        agents_to_deploy, agent_sources = self.multi_source_service.get_agents_for_deployment(
+        # Get agents with version comparison and cleanup
+        agents_to_deploy, agent_sources, cleanup_results = self.multi_source_service.get_agents_for_deployment(
             system_templates_dir=system_templates_dir,
             project_agents_dir=project_agents_dir,
             user_agents_dir=user_agents_dir,
             working_directory=self.working_directory,
             excluded_agents=excluded_agents,
-            config=config
+            config=config,
+            cleanup_outdated=True  # Enable cleanup by default
         )
         
         # Compare with deployed versions if agents directory exists
@@ -1113,11 +1167,32 @@ class AgentDeploymentService(AgentDeploymentInterface):
                 self.logger.info(f"Version upgrades available for {len(comparison_results['version_upgrades'])} agents")
             if comparison_results.get("source_changes"):
                 self.logger.info(f"Source changes for {len(comparison_results['source_changes'])} agents")
+            
+            # Filter agents based on comparison results (unless force_rebuild is set)
+            if not force_rebuild:
+                # Only deploy agents that need updates or are new
+                agents_needing_update = set(comparison_results.get("needs_update", []))
+                
+                # Extract agent names from new_agents list (which contains dicts)
+                new_agent_names = [
+                    agent["name"] if isinstance(agent, dict) else agent
+                    for agent in comparison_results.get("new_agents", [])
+                ]
+                agents_needing_update.update(new_agent_names)
+                
+                # Filter agents_to_deploy to only include those needing updates
+                filtered_agents = {
+                    name: path for name, path in agents_to_deploy.items()
+                    if name in agents_needing_update
+                }
+                agents_to_deploy = filtered_agents
+                
+                self.logger.info(f"Filtered to {len(agents_to_deploy)} agents needing deployment")
         
         # Convert to list of Path objects
         template_files = list(agents_to_deploy.values())
         
-        return template_files, agent_sources
+        return template_files, agent_sources, cleanup_results
 
     # ================================================================================
     # Interface Adapter Methods
