@@ -1,15 +1,14 @@
 """Agent memory and persistence services."""
 
-from .agent_memory_manager import (
-    AgentMemoryManager,
-    get_memory_manager,
-)
+from .agent_memory_manager import AgentMemoryManager, get_memory_manager
 from .agent_persistence_service import (
     AgentPersistenceService,
-    PersistenceStrategy,
     PersistenceOperation,
     PersistenceRecord,
+    PersistenceStrategy,
 )
+from .content_manager import MemoryContentManager
+from .template_generator import MemoryTemplateGenerator
 
 __all__ = [
     "AgentMemoryManager",
@@ -18,4 +17,6 @@ __all__ = [
     "PersistenceStrategy",
     "PersistenceOperation",
     "PersistenceRecord",
-]
\ No newline at end of file
+    "MemoryTemplateGenerator",
+    "MemoryContentManager",
+]
