@@ -3,7 +3,7 @@ Simplified MCP Stdio Server
 ============================
 
 A proper stdio-based MCP server that communicates via JSON-RPC over stdin/stdout.
-This server is spawned on-demand by Claude Desktop/Code and exits when the connection closes.
+This server is spawned on-demand by Claude Code/Code and exits when the connection closes.
 
 WHY: MCP servers should be simple stdio-based processes that Claude can spawn and control.
 They should NOT run as persistent background services with lock files.
@@ -15,7 +15,10 @@ use JSON-RPC protocol, and exit cleanly when stdin closes.
 import asyncio
 import json
 import logging
+import os
 import sys
+import time
+from pathlib import Path
 from typing import Any, Dict, Optional
 
 # Import MCP SDK components
@@ -28,6 +31,7 @@ from mcp.types import TextContent, Tool
 from pydantic import BaseModel
 
 from claude_mpm.core.logger import get_logger
+from claude_mpm.services.mcp_gateway.core.singleton_manager import get_gateway_manager
 
 # Import unified ticket tool if available
 try:
@@ -45,7 +49,7 @@ def apply_backward_compatibility_patches():
     Apply backward compatibility patches for MCP protocol differences.
     
     This function patches the MCP Server to handle missing clientInfo
-    in initialize requests from older Claude Desktop versions.
+    in initialize requests from older Claude Code versions.
     """
     try:
         from mcp.server import Server
@@ -114,7 +118,7 @@ class SimpleMCPServer:
     A simple stdio-based MCP server implementation.
 
     WHY: This server follows the MCP specification for stdio communication,
-    making it compatible with Claude Desktop/Code's MCP client.
+    making it compatible with Claude Code/Code's MCP client.
 
     DESIGN DECISIONS:
     - No persistent state or lock files
@@ -135,6 +139,11 @@ class SimpleMCPServer:
         self.name = name
         self.version = version
         self.logger = get_logger("MCPStdioServer")
+        self.startup_time = time.time()
+        
+        # Log startup timing
+        self.logger.info(f"Initializing MCP server {name} v{version}")
+        start_time = time.time()
 
         # Apply backward compatibility patches before creating server
         apply_backward_compatibility_patches()
@@ -144,6 +153,10 @@ class SimpleMCPServer:
 
         # Register default tools
         self._register_tools()
+        
+        # Log initialization time
+        init_time = time.time() - start_time
+        self.logger.info(f"MCP server initialized in {init_time:.2f} seconds")
 
     async def _summarize_content(
         self, content: str, style: str, max_length: int
